# Generated by Django 2.1.2 on 2018-12-10 16:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user_activities', '0002_auto_20181023_1337'),
    ]

    operations = [
        migrations.AlterField(
            model_name='comment',
            name='text',
            field=models.CharField(blank=True, max_length=255),
        ),
        migrations.AlterField(
            model_name='review',
            name='text',
            field=models.CharField(blank=True, max_length=255),
        ),
    ]
